@@ -1,17 +1,15 @@
 """fastapi-mvc."""
 from fastapi_mvc.commands.base import Command
 from fastapi_mvc.commands.invoker import Invoker
+from fastapi_mvc.commands.generate import Generate
+from fastapi_mvc.commands.run_shell import RunShell
 from fastapi_mvc.commands.new_project import GenerateNewProject
-from fastapi_mvc.commands.run_uvicorn import RunUvicorn
-from fastapi_mvc.commands.install_project import InstallProject
-from fastapi_mvc.commands.verify_install import VerifyInstall
 
 
 __all__ = (
     Command,
     Invoker,
+    Generate,
+    RunShell,
     GenerateNewProject,
-    RunUvicorn,
-    InstallProject,
-    VerifyInstall,
 )
